git: b15a632c418f - main - if_hn: Fix a few typos in comments and a sysctl description

From: Gordon Bergling <gbe_at_FreeBSD.org>
Date: Tue, 30 Nov 2021 09:42:16 UTC
The branch main has been updated by gbe (doc committer):

URL: https://cgit.FreeBSD.org/src/commit/?id=b15a632c418f6532fe7c3002b4085c61b1e278b0

commit b15a632c418f6532fe7c3002b4085c61b1e278b0
Author:     Gordon Bergling <gbe@FreeBSD.org>
AuthorDate: 2021-11-30 09:35:14 +0000
Commit:     Gordon Bergling <gbe@FreeBSD.org>
CommitDate: 2021-11-30 09:35:14 +0000

    if_hn: Fix a few typos in comments and a sysctl description
    
    - s/segement/segment/
    
    MFC after:      3 days
---
 sys/dev/hyperv/netvsc/if_hn.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/sys/dev/hyperv/netvsc/if_hn.c b/sys/dev/hyperv/netvsc/if_hn.c
index 0ec398bed670..d562a937ecad 100644
--- a/sys/dev/hyperv/netvsc/if_hn.c
+++ b/sys/dev/hyperv/netvsc/if_hn.c
@@ -457,11 +457,11 @@ static void			hn_start_txeof_taskfunc(void *, int);
 SYSCTL_NODE(_hw, OID_AUTO, hn, CTLFLAG_RD | CTLFLAG_MPSAFE, NULL,
     "Hyper-V network interface");
 
 /* Trust tcp segements verification on host side. */
 static int			hn_trust_hosttcp = 1;
 SYSCTL_INT(_hw_hn, OID_AUTO, trust_hosttcp, CTLFLAG_RDTUN,
     &hn_trust_hosttcp, 0,
-    "Trust tcp segement verification on host side, "
+    "Trust tcp segment verification on host side, "
     "when csum info is missing (global setting)");
 
 /* Trust udp datagrams verification on host side. */
@@ -5116,7 +5116,7 @@ hn_create_rx_data(struct hn_softc *sc, int ring_cnt)
 	SYSCTL_ADD_PROC(ctx, child, OID_AUTO, "trust_hosttcp",
 	    CTLTYPE_INT | CTLFLAG_RW | CTLFLAG_MPSAFE, sc, HN_TRUST_HCSUM_TCP,
 	    hn_trust_hcsum_sysctl, "I",
-	    "Trust tcp segement verification on host side, "
+	    "Trust tcp segment verification on host side, "
 	    "when csum info is missing");
 	SYSCTL_ADD_PROC(ctx, child, OID_AUTO, "trust_hostudp",
 	    CTLTYPE_INT | CTLFLAG_RW | CTLFLAG_MPSAFE, sc, HN_TRUST_HCSUM_UDP,
@@ -457,11 +457,11 @@ static void			hn_start_txeof_taskfunc(void *, int);
     "Hyper-V network interface");
 
-/* Trust tcp segements verification on host side. */
+/* Trust tcp segment verification on host side. */
 static int			hn_trust_hosttcp = 1;
 SYSCTL_INT(_hw_hn, OID_AUTO, trust_hosttcp, CTLFLAG_RDTUN,